<?php

namespace Litecms\Email\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Email\Http\Requests\EmailsRequest;
use Litecms\Email\Interfaces\EmailsRepositoryInterface;
use Litecms\Email\Models\Emails;

/**
 * Resource controller class for emails.
 */
class EmailsResourceController extends BaseController
{

    /**
     * Initialize emails resource controller.
     *
     * @param type EmailsRepositoryInterface $emails
     *
     * @return null
     */
    public function __construct(EmailsRepositoryInterface $emails)
    {
        parent::__construct();
        $this->repository = $emails;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Email\Repositories\Criteria\EmailsResourceCriteria::class);
    }

    /**
     * Display a list of emails.
     *
     * @return Response
     */
    public function index(EmailsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Email\Repositories\Presenter\EmailsPresenter::class)
                ->$function();
        }

        $emails = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('email::emails.names'))
            ->view('email::emails.index', true)
            ->data(compact('emails', 'view'))
            ->output();
    }

    /**
     * Display emails.
     *
     * @param Request $request
     * @param Model   $emails
     *
     * @return Response
     */
    public function show(EmailsRequest $request, Emails $emails)
    {

        if ($emails->exists) {
            $view = 'email::emails.show';
        } else {
            $view = 'email::emails.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('email::emails.name'))
            ->data(compact('emails'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new emails.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(EmailsRequest $request)
    {

        $emails = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('email::emails.name')) 
            ->view('email::emails.create', true) 
            ->data(compact('emails'))
            ->output();
    }

    /**
     * Create new emails.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(EmailsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $emails                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('email::emails.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('email/emails/' . $emails->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/email/emails'))
                ->redirect();
        }

    }

    /**
     * Show emails for editing.
     *
     * @param Request $request
     * @param Model   $emails
     *
     * @return Response
     */
    public function edit(EmailsRequest $request, Emails $emails)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('email::emails.name'))
            ->view('email::emails.edit', true)
            ->data(compact('emails'))
            ->output();
    }

    /**
     * Update the emails.
     *
     * @param Request $request
     * @param Model   $emails
     *
     * @return Response
     */
    public function update(EmailsRequest $request, Emails $emails)
    {
        try {
            $attributes = $request->all();

            $emails->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('email::emails.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('email/emails/' . $emails->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('email/emails/' . $emails->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the emails.
     *
     * @param Model   $emails
     *
     * @return Response
     */
    public function destroy(EmailsRequest $request, Emails $emails)
    {
        try {

            $emails->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('email::emails.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('email/emails/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('email/emails/' . $emails->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple emails.
     *
     * @param Model   $emails
     *
     * @return Response
     */
    public function delete(EmailsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('email::emails.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('email/emails'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/email/emails'))
                ->redirect();
        }

    }

    /**
     * Restore deleted emails.
     *
     * @param Model   $emails
     *
     * @return Response
     */
    public function restore(EmailsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('email::emails.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/email/emails'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/email/emails/'))
                ->redirect();
        }

    }

}
